@@ -27,6 +27,7 @@ import (
 	"net/http/httptrace"
 	"net/textproto"
 	"net/url"
+	"os"
 	"strconv"
 	"strings"
 	"sync"
@@ -322,7 +323,7 @@ func ProbeHTTP(ctx context.Context, target string, module config.Module, registr
 	targetPort := targetURL.Port()
 
 	var ip *net.IPAddr
-	if !module.HTTP.SkipResolvePhaseWithProxy || module.HTTP.HTTPClientConfig.ProxyURL.URL == nil {
+	if !module.HTTP.SkipResolvePhaseWithProxy || module.HTTP.HTTPClientConfig.ProxyConfig.ProxyURL.URL == nil || module.HTTP.HTTPClientConfig.ProxyConfig.ProxyFromEnvironment {
 		var lookupTime float64
 		ip, lookupTime, err = chooseProtocol(ctx, module.HTTP.IPProtocol, module.HTTP.IPProtocolFallback, targetHost, registry, logger)
 		durationGaugeVec.WithLabelValues("resolve").Add(lookupTime)
@@ -408,6 +409,17 @@ func ProbeHTTP(ctx context.Context, target string, module config.Module, registr
 		body = strings.NewReader(httpConfig.Body)
 	}
 
+	// If a body file is configured, add its content to the request.
+	if httpConfig.BodyFile != "" {
+		body_file, err := os.Open(httpConfig.BodyFile)
+		if err != nil {
+			level.Error(logger).Log("msg", "Error creating request", "err", err)
+			return
+		}
+		defer body_file.Close()
+		body = body_file
+	}
+
 	request, err := http.NewRequest(httpConfig.Method, targetURL.String(), body)
 	if err != nil {
 		level.Error(logger).Log("msg", "Error creating request", "err", err)
